@@ -4,8 +4,9 @@
 An object-oriented framework for command-line apps.
 """
 
-__version__ = '0.10.1'
+__version__ = '0.12.0'
 
+# Define the public API
 from .app import App, FromParams
 from .model import init, load, reload
 from .params.param import param, Key
@@ -14,5 +15,6 @@ from .params.inherited import inherited_param
 from .configs.configs import *
 from .configs.layers import Layer, not_found
 from .configs.attrs import config_attr
+from .configs.on_load import on_load
 from .errors import *
 from .utils import lookup
